@@ -4,7 +4,10 @@ use Modern::Perl;
 use Moo;
 use MooX::Types::MooseLike::Base qw(:all);
 use Data::Dumper;
+use Ref::Util qw(is_plain_arrayref);
 use namespace::clean;
+Log::Log4perl->wrapper_register(__PACKAGE__);
+
 BEGIN {
   extends 'HTTP::MultiGet';
 }
@@ -17,24 +20,25 @@ AnyEvent::HTTP::MultiGet - AnyEvent Loop Control Freindly LWP Like agent
 
 =head1 SYNOPSIS
 
+  use Modern::Perl;
   use AnyEvent::HTTP::MultiGet;
   use AnyEvent::Loop;
-  use Test::More;
-  use Data::Dumper;
 
   my $self=AnyEvent::HTTP::MultiGet->new();
   my $count=0;
   TEST_LOOP: {
     my $req=HTTP::Request->new(GET=>'http://google.com');
+    my $req_b=HTTP::Request->new(GET=>'https://127.0.0.1:5888');
     my @todo=HTTP::Request->new(GET=>'http://yahoo.com');
     push @todo,HTTP::Request->new(GET=>'http://news.com');
+    push @todo,HTTP::Request->new(GET=>'https://news.com');
+
     my $total=2 + scalar(@todo);
 
-    my $req_b=HTTP::Request->new(GET=>'https://127.0.0.1:5888');
     my $code;
     $code=sub {
       my ($obj,$request,$result)=@_;
-      diag sprintf 'HTTP Response code: %i',$result->code;
+      printf 'HTTP Response code: %i'."\n",$result->code;
       ++$count;
       if(my $next=shift @todo) {
         $self->add_cb($req,$code);
@@ -49,6 +53,66 @@ AnyEvent::HTTP::MultiGet - AnyEvent Loop Control Freindly LWP Like agent
     AnyEvent::Loop::run;
   }
 
+Handling Multiple large http requests at once
+
+  use Modern::Perl;
+  use AnyEvent::HTTP::MultiGet;
+  use AnyEvent::Loop;
+
+  my $self=AnyEvent::HTTP::MultiGet->new();
+  my $chunks=0;
+  my $count=0;
+
+
+  my $req=HTTP::Request->new(GET=>'https://google.com');
+  my $req_b=HTTP::Request->new(GET=>'https://yahoo.com');
+  my $req_c=HTTP::Request->new(GET=>'https://news.com');
+  $total=3;
+
+  my @todo;
+  push @todo,HTTP::Request->new(GET=>'https://127.0.0.1:5888');
+  push @todo,HTTP::Request->new(GET=>'https://127.0.0.1:5887');
+  push @todo,HTTP::Request->new(GET=>'https://127.0.0.1:5886');
+  push @todo,HTTP::Request->new(GET=>'https://127.0.0.1:5885');
+  $total +=scalar(@todo);
+
+  TEST_LOOP: {
+    my $on_body=sub {
+      my ($getter,$request,$headers,$chunk)=@_;
+      # 0: Our AnyEvent::HTTP::MultiGet instance
+      # 1: the HTTP::Request object
+      # 2: An HTTP::Headers object representing the current headers
+      # 3: Current Data Chunk
+
+      ++$chunks;
+      printf 'request is %s'."\n",$request->uri;
+      printf 'status code was: %i'."\n",$headers->header('Status');
+      printf 'content length was: %i'."\n",length($body);
+    };
+
+    my $code;
+    $code=sub {
+       my ($obj,$request,$result)=@_;
+      printf 'HTTP Response code: %i %s'."\n",$result->code,$request->url;
+      ++$count;
+      print "We are at response $count\n";
+      if(my $next=shift @todo) {
+        $self->add_cb([$next,on_body=>$on_body],$code);
+        $self->run_next;
+      }
+      no warnings;
+      last TEST_LOOP if $count==$total;
+    };
+    $self->add_cb([$req,on_body=>$on_body],$code);
+    $self->add_cb([$req_b,on_body=>$on_body],$code);
+    $self->add_cb([$req_c,on_body=>$on_body],$code);
+
+    $self->run_next;
+    AnyEvent::Loop::run;
+  }
+
+
+
 =head1 DESCRIPTION
 
 This class provides an AnyEvent::Loop::run frienddly implementation of HTTP::MultiGet.
@@ -100,12 +164,17 @@ around BUILDARGS => sub {
 
 Adds a request with a callback handler.
 
+=item * my $id=$self->add_cb([$request,key=>value],$code);
+
+Wrapping [$request] allows passing additional key value to L<AnyEvent::HTTP::Request>, with one exception, on_body=>$code is wrapped an additional callback.
+
 =cut
 
 sub add_cb {
   my ($self,$request,$code)=@_;
   my ($id)=$self->add($request);
-  $self->cb_map->{$id}=[$code,$request];
+  my $req=is_plain_arrayref($request) ? $request->[0] : $request;
+  $self->cb_map->{$id}=[$code,$req];
   return $id;
 }
 
